extern char *home_dir;

#define min(x,y) (x>y ? y: x)
#define max(x,y) (x>y ? x: y)

void refresh_screen (void *);

#if defined(ultrix) || defined(AUX)
char *strdup (char *);
#endif

/* AIX compiler doesn't understand '\e' */
#define ESC_CHAR '\033'

#ifdef USE_BSD_CURSES
    #define xgetch x_getch
#else
    #define xgetch getch
#endif

